#!/usr/bin/env python3
import sys
import matplotlib.pyplot as plt
import matplotlib
import matplotlib.cm as cm
matplotlib.rcParams['mathtext.fontset'] = 'stix'
matplotlib.rcParams['font.family'] = 'STIXGeneral'

names =  ["amulet2.1",  "teluma", "revsca2",    "dyposub", "abc"]
labels = ["AMulet 2 [11]", "TeluMA", "RevSCA-2.0 [16]", "DyPoSub [17]", "ABC-based [5]"]
cols =   ["magenta",     "blue",          "orange",     "green",  "red"]
markers =["+",         "v", "^", "3", "p", "s", "X"]
order= [2,1,3,4,5,6,7]


ypoint = range(1, 385)

for i in range(len(names)):
   index = order[i]-1
   name = names[index]
   time_file_name = name+"/"+name+".time"
   time_file= open(time_file_name, "r")
   unsigned_times = time_file.read().split('\n')

   times = unsigned_times[:-1]



   times  = [float(i) for i in times if float(i)<300]
   times = sorted(times)

   length=len(times)

   line,=plt.plot(times, ypoint[0:length], color=cols[index], marker = markers[index], fillstyle='none', label=labels[index])
   line.set_clip_on(False)


plt.legend(loc='upper left', bbox_to_anchor=(0.68, 0.31), fontsize=10)
plt.vlines(300, 0, 200, linestyles="dashed", colors = "gray")
plt.hlines(192, 0, 350, linestyles="dashed", colors = "gray")
plt.axis([0.3, 350,0, 200])
#plt.title("64-bit multipliers (384 instances)", fontsize=16)
plt.ylabel("Number of solved instances", fontsize=16)
plt.xscale("log")
plt.xlabel("CPU time, time limit = 300 sec", fontsize=16)
plt.tick_params(labelsize=14)
plt.grid()
plt.savefig("aoki.pdf", bbox_inches = 'tight', pad_inches = 0.1)
